#
# fishing.R, 25 Sep 21
#
# Data from:
# Calibrating the mental number line
# Véronique Izard and Stanislas Dehaene
#

library("colorspace")
library("plyr")

par(bty="l")
par(las=1)
par(pch="+")


# Plot number of stimulus values seen, for a single response value, e.g., a round number
fixed_resp=function(resp_val, col_str="black")
{
frs_cnt=count(subset(de1, resp == resp_val)$stim)
lines(frs_cnt, col=col_str)
}


# Plot number of stimulus values seen, for a single response value (e.g., a round number)
# broken down by Subject
fixed_person_resp=function(resp_val)
{
plot(0.1, type="n",
     	yaxs="i",
	xlim=c(5, 100), ylim=c(0, 80),
	xlab="Stimulus", ylab="Occurrences")

frs=subset(de1, resp == resp_val)
dum=sapply(people, function(X) lines(count(subset(frs, Subject == X)$stim), col=person_col[X]))
}


# Plot particular round number values for a given person
person_spike_resp=function(person_id)
{
plot(0.1, type="n",
     	yaxs="i",
	xlim=c(5, 100), ylim=c(0, 21),
	xlab="Stimulus", ylab="Occurrences")

frs=subset(de1, Subject == person_id)
dum=sapply(1:length(spike_vals), function(X) lines(count(subset(frs, resp == spike_vals[X])$stim), col=spike_col[X]))
}



# Two datasets
de1=read.csv("data_experiment1.txt", as.is=TRUE, sep="\t")
de2=read.csv("data_experiment2.txt", as.is=TRUE, sep="\t")

pal_col=rainbow(6)

people=unique(de1$Subject)
person_col=rainbow(length(people))

spike_vals=c(15, 20, 25, 30, 50)
spike_col=rainbow(length(spike_vals))

pal_col=rainbow(3)

plot(de1$stim, de1$resp, log="xy", col=pal_col[3],
	xlab="Stimulus", ylab="Response")
lines(c(1, 100), c(1, 100), col=pal_col[2])

plot(de2$stim, de2$resp, log="xy")

# Usual power model fit
de1_mod=glm(log(resp) ~ log(stim), data=de1)
summary(de1_mod)
x_vals=1:100
pred=predict(de1_mod, newdata=data.frame(stim=x_vals))
lines(x_vals, exp(pred), col=pal_col[1])

de2_mod=glm(log(resp) ~ log(stim), data=de2)
summary(de2_mod)

# Various fits using more variables
# de_mod=glm(log(resp) ~ log(stim)+factor(Subject)+area*factor(condition)+log(dotsize), data=de1)
# de_mod=glm(log(resp) ~ log(stim)+factor(Subject)*log(Trial), data=de1)
# de_mod=glm(log(resp) ~ log(stim)+factor(Subject)*log(Trial+50), data=de1) # add experience
# de_mod=glm(log(resp) ~ log(stim)+area+log(dotsize)+factor(Subject), data=de1)
de_mod=glm(log(resp) ~ log(stim)+factor(Subject), data=de1) # Explains almost 90% of variance
summary(de_mod)

# Subject model coefficients
exp(coef(de_mod))

resp_cnt=count(de1$resp)
stim_cnt=count(de1$stim)

# Look for round number usage
plot(stim_cnt)
# plot(density(de1$stim))

srcnt=resp_cnt[order(resp_cnt$freq), ]

pal_col=rainbow(2)
plot(resp_cnt, type="l", col=pal_col[2],
     	xaxs="i", yaxs="i",
	xlim=c(0, 100), ylim=c(0, 1600),
	xlab="Response", ylab="Occurrences")

# Known spikes in occurrences
text(15, 970, "15", col=pal_col[1])
text(20, 1500, "20", col=pal_col[1])
text(25, 1440, "25", col=pal_col[1])
text(30, 1500, "30", col=pal_col[1])
text(35, 870, "35", col=pal_col[1])
text(40, 950, "40", col=pal_col[1])
text(50, 710, "50", col=pal_col[1])
text(75, 690, "75", col=pal_col[1])

# Show round number use by Subject
plot(0.1, type="n", log="y",
     	yaxs="i",
	xlim=c(5, 100), ylim=c(1, 1000),
	xlab="Stimulus", ylab="Occurrences")

dum=sapply(people, function(X) lines(count(subset(de1, Subject == X)$resp), col=person_col[X]))

plot(0.1, type="n",
     	yaxs="i",
	xlim=c(5, 90), ylim=c(0, 35),
	xlab="Stimulus", ylab="Occurrences")

fixed_resp(20, pal_col[1])
fixed_resp(25, pal_col[2])
fixed_resp(30, pal_col[3])
fixed_resp(40, pal_col[4])
fixed_resp(50, pal_col[5])
fixed_resp(75, pal_col[6])

fixed_person_resp(20)

person_spike_resp(1)

# Tag each subject with the sequence of inducers they experienced
t1=subset(de2, trial == 1)
t552=subset(de2, trial == 552)

de2$inducer_seq=""
de2$induc_seq[(t1$inducer == 25) & (t552$inducer == 30)]="LX" # Low eXact
de2$induc_seq[(t1$inducer == 39) & (t552$inducer == 30)]="HX" # High eXact
de2$induc_seq[(t1$inducer == 30) & (t552$inducer == 25)]="XL" # eXact Low
de2$induc_seq[(t1$inducer == 30) & (t552$inducer == 39)]="XH" # eXact High
# table(de2$induc_seq)

de2_mod=glm(log(resp) ~ log(stim)+log(inducer)+factor(Subject), data=de2) # Explains 83% of variance
# # Adding induc_seq haszero impact on model
# de2_mod=glm(log(resp) ~ log(stim)+log(inducer)+induc_seq+factor(Subject), data=de2)
summary(de2_mod)



#
# jeabehav_N1356.R,  6 Dec 19
# Data from:
# Probability Relations Within Response Sequences Under Ratio Reinforcement
# Francis Mechner
#
# Example from:
# Evidence-based Software Engineering: based on the publicly available data
# Derek M. Jones
#
# TAG experiment_human experiment_rat number-line_rat

rats=read.csv("/home/ESEUR-code-data/developers/jeabehav_N1356.csv.xz", as.is=TRUE)

pal_col=rainbow(length(unique(rats$Center)))

N1=subset(rats, N == 1)
N1$col=pal_col[N1$Center/4]

plot(0, type="n",
	yaxs="i",
	xlim=range(N1$Offset), ylim=range(N1$Prob),
	xlab="Number of presses", ylab="Probability")

d_ply(N1, .(Center), function(df) lines(df$Offset, df$Prob, type="b", col=df$col))

legend(x="topright", legend=paste0("Target presses = ", c(" 4", " 8", "12", "16")), bty="n", fill=pal_col, cex=1.2)

